@@ -159,14 +159,17 @@ impl FuzzProject {
             cmd.arg("-Z").arg("build-std");
         }
 
-        let mut rustflags: String = "--cfg fuzzing \
-                                     -Cpasses=sancov \
+        let mut rustflags: String = "-Cpasses=sancov-module \
                                      -Cllvm-args=-sanitizer-coverage-level=4 \
                                      -Cllvm-args=-sanitizer-coverage-trace-compares \
                                      -Cllvm-args=-sanitizer-coverage-inline-8bit-counters \
                                      -Cllvm-args=-sanitizer-coverage-pc-table"
             .to_owned();
 
+        if !build.no_cfg_fuzzing {
+            rustflags.push_str(" --cfg fuzzing");
+        }
+
         if !build.strip_dead_code {
             rustflags.push_str(" -Clink-dead-code");
         }
@@ -459,14 +462,22 @@ impl FuzzProject {
                 eprintln!();
             }
 
+            let fuzz_dir = if self.fuzz_dir_is_default_path() {
+                String::new()
+            } else {
+                format!(" --fuzz-dir {}", self.fuzz_dir().display())
+            };
+
             eprintln!(
-                "Reproduce with:\n\n\tcargo fuzz run{options} {target} {artifact}\n",
+                "Reproduce with:\n\n\tcargo fuzz run{fuzz_dir}{options} {target} {artifact}\n",
+                fuzz_dir = &fuzz_dir,
                 options = &run.build,
                 target = &run.target,
                 artifact = artifact.display()
             );
             eprintln!(
-                "Minimize test case with:\n\n\tcargo fuzz tmin{options} {target} {artifact}\n",
+                "Minimize test case with:\n\n\tcargo fuzz tmin{fuzz_dir}{options} {target} {artifact}\n",
+                fuzz_dir = &fuzz_dir,
                 options = &run.build,
                 target = &run.target,
                 artifact = artifact.display()
@@ -822,6 +833,10 @@ impl FuzzProject {
             targets: Vec::new(),
         })
     }
+
+    fn fuzz_dir_is_default_path(&self) -> bool {
+        self.fuzz_dir.ends_with(DEFAULT_FUZZ_DIR)
+    }
 }
 
 fn collect_targets(value: &toml::Value) -> Vec<String> {
